@@ -18,7 +18,8 @@ hydro.config.suppress_callback_exceptions=True
 
 # HYDRO ROUTING 
 def hydro_url_route_parser(url): 
-    if url == None or url == "":
+    print(url)
+    if url == None or url == "/":
         return None
     if url[0] == "/":
         url = url[1:]
